@@ -6,7 +6,7 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.76';
+our $VERSION = '1.77';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -54,6 +54,15 @@ sub new_p {
 
 	my @candidates = $opt{get_station}( $opt{station} );
 
+	if ( @candidates != 1 and $opt{station} =~ m{^\d+$} ) {
+		@candidates = (
+			[
+				"D$opt{station}", "Betriebsstelle nicht bekannt $opt{station}",
+				$opt{station}
+			]
+		);
+	}
+
 	if ( @candidates == 0 ) {
 		return $promise->reject('station not found');
 	}
@@ -978,7 +987,7 @@ Non-blocking variant (EXPERIMENTAL):
 
 =head1 VERSION
 
-version 1.76
+version 1.77
 
 =head1 DESCRIPTION
 
